@@ -18,12 +18,11 @@ static void _blur( SDL_Surface *source, SDL_Surface *target, int radius, char ve
     int color_cnt = 0;
     int x,y,ra,n,s,o1,o2;
     double r2;
+    int pxcnt = 0;
     int w = source->w;
     int h = source->h;
     SDL_PixelFormat *source_format = (SDL_PixelFormat *)source->format;
     SDL_PixelFormat *target_format = (SDL_PixelFormat *)target->format;
-    
-    /* Surface pixels shorthand */
     Uint32 *source_pixels = (Uint32 *) source->pixels;
     Uint32 *target_pixels = (Uint32 *) target->pixels;
 
@@ -32,30 +31,42 @@ static void _blur( SDL_Surface *source, SDL_Surface *target, int radius, char ve
     o2 = (vertical)?0:1;
     r2 = radius*2+1;
     
+    SDL_LockSurface(source);
+    SDL_LockSurface(target);
     for( y = 0; y < h; y++ ){
         for( x = 0; x < w; x++ ){
             color_cnt = 0;sr = 0;sg = 0;sb = 0;sa = 0;
+            ra = -radius;
             n = (vertical)?y:x;
-            
-            for( ra = -radius; ra <= radius; ra++ ){
+
+            while( ra <= radius ){
                 if( (n+ra) >= 0 && (n+ra) < s ){
-                    pix = source_pixels[(int)( ( (y + (ra * o1)) * w) + (x + (ra * o2)) )];
+                    pix = source_pixels[pxcnt + (int)( ((ra * o1) * w) + (ra * o2))];
                     SDL_GetRGBA( pix, source_format, &r, &g, &b, &a );
                     sr += r;sg += g;sb += b;sa += a;
                     color_cnt++;
                 }
+                ra++;
             }
-            sr = sr/r2;sg = sg/r2;
-            sb = sb/r2;sa = sa/r2;
-            pix = SDL_MapRGBA( target_format, (Uint8)sr, (Uint8)sg, (Uint8)sb, (Uint8)sa );
-            target_pixels[ (y*w)+x ] = pix;
+            pxcnt++;
+            if(sa == 0) continue;
+            if(color_cnt <= 1) continue;
+            sr = sr/color_cnt;
+            sg = sg/color_cnt;
+            sb = sb/color_cnt;
+            sa = sa/color_cnt;
+            pix = SDL_MapRGBA( target_format, (Uint8)sr, (Uint8)sg, 
+                (Uint8)sb, (Uint8)sa);
+            target_pixels[pxcnt-1] = pix;
         }
-    }   
+    }
+    SDL_UnlockSurface(source);
+    SDL_UnlockSurface(target);
 }
 
 
 /*
-    Simple random noise. [RGB]*RAND
+    Simple random noise. [RGB]+RAND
 */
 static PyObject* noise( PyObject* self, PyObject* args )
 {
@@ -101,6 +112,56 @@ static PyObject* noise( PyObject* self, PyObject* args )
     return Py_None;
 }
 
+
+/*
+    noise blur
+*/
+static PyObject* noiseBlur( PyObject* self, PyObject* args )
+{
+    PyObject* py_surface = NULL;
+    Uint32 *pixels;
+    int w,h,x,y = 0;
+    Uint32 pixel;
+    SDL_PixelFormat *format = NULL;
+
+    int radius = 5;
+    char blend = 0;
+    Uint8 r,g,b,a,tr,tg,tb,ta;
+    int rnd,dx,dy;
+
+    PY_PARSEARGS_BEGIN
+        "O|ib", &py_surface, &radius, &blend
+    PY_PARSEARGS_END
+
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
+    //srand();
+
+    for( y = 0; y < h; y ++ ){
+        for( x = 0; x < w; x ++ ){
+            dx = x + ((rand() % (radius * 2)) - radius);
+            dy = y + ((rand() % (radius * 2)) - radius);
+            if( dx < 0 || dx >= w || dx == x ) continue;
+            if( dy < 0 || dy >= h || dy == y ) continue;
+            pixel = pixels[(dy*w)+dx];
+            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
+            if(blend){
+                pixel = pixels[(y*w)+x];
+                SDL_GetRGBA( pixel, format, &tr, &tg, &tb, &ta );
+                r = (tr + r)/2;
+                g = (tg + g)/2;
+                b = (tb + b)/2;
+            }
+            pixel = SDL_MapRGBA( format, r, g, b, a );
+            pixels[ (y*w)+x ] = pixel;
+
+        }
+    }
+    
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
+
 /*
     Simple image scratching.
 */
@@ -361,6 +422,8 @@ static PyObject* hvBlur(PyObject* self, PyObject* args)
     /* Switch original => temp with vertical blur */
     _blur( copy_surface, surface->surf, radius, vertical );
     
+    SDL_FreeSurface(copy_surface);
+
     Py_INCREF( Py_None );
     return Py_None;
 }
@@ -370,6 +433,7 @@ static PyMethodDef FiltersMethods[] = {
     {"blur", blur, METH_VARARGS, "Blur surface"},
     {"hvBlur", hvBlur, METH_VARARGS, "Horizonal/vertical blur"},
     {"noise", noise, METH_VARARGS, "Simple surface noise"},
+    {"noiseBlur", noiseBlur, METH_VARARGS, "Simple surface noise"},
     {"shadow", shadow, METH_VARARGS, "Create RGBA surface shadow"},
     {"scratch", scratch, METH_VARARGS, "Create RGBA surface shadow"},
     {NULL, NULL, NULL, NULL}
