@@ -15,6 +15,7 @@ class Tester:
         self.tests = {}
         self.order = []
         self.results = {}
+        self.result_surfaces = {}
         self.times_start = {}
         self.times_result = {}
         self.types = ["modify-return", "modify-inplace", "make"]
@@ -40,7 +41,12 @@ class Tester:
         return True
 
     def saveImage(self, name, image):
-        pygame.image.save(image, "out_%s.png" % name)
+        self.result_surfaces[name] = image
+
+    def saveAll(self):
+        for name in self.result_surfaces:
+            image = self.result_surfaces[name]
+            pygame.image.save(image, "out_%s.png" % name)
 
     def meterStart(self, name):
         self.times_start[name] = time.time()
@@ -53,9 +59,10 @@ class Tester:
         for n in xrange(self.num):
             for test in self.order:
                 self.doTest(test)
+        self.saveAll()
 
     def doTest(self, name):
-        print "Test: %s" % name
+        print "%sTest: %s" % ("\b"*80, name),
         try:
             test = self.tests[name]
             source = test[3].copy()
@@ -97,12 +104,11 @@ source_rgba = pygame.image.load("source_rgba.png")
 source_mask = pygame.image.load("source_mask.png")
 source_colorize = pygame.image.load("source_colorize.png")
 
-tester = Tester("source_rgb.png", 2)
+tester = Tester("source_rgb.png", 10)
 
 tester.addTests([
                 ("color.colorize", "modify-inplace",
                  pgext.color.colorize, [120, 0, -30, 10], source_colorize),
-
                 ("color.greyscale1", "modify-inplace",
                  pgext.color.greyscale, []),
                 ("color.greyscale2", "modify-inplace",
@@ -110,14 +116,18 @@ tester.addTests([
                 ("color.greyscale3", "modify-inplace",
                  pgext.color.greyscale, [2]),
                 ("color.invert", "modify-inplace", pgext.color.invert, []),
-                
                 ("color.hue", "modify-inplace", pgext.color.hue, [80]),
                 ("color.saturation", "modify-inplace",
                  pgext.color.saturation, [30, 2]),
                 ("color.lightness", "modify-inplace",
                  pgext.color.lightness, [20]),
                 ("color.value", "modify-inplace", pgext.color.value, [-50]),
-
+                ("color.multiply1", "modify-inplace",
+                 pgext.color.multiply, [2.5]),
+                ("color.multiply2", "modify-inplace",
+                 pgext.color.multiply, [0.4]),
+                ("color.multiply3", "modify-inplace",
+                 pgext.color.multiply, [0.0, 1, 0, 1]),
                 ("color.setColor", "modify-inplace",
                  pgext.color.setColor, [(120, 0, 200)], source_rgba),
                 ("color.setAlpha", "modify-inplace",
@@ -127,6 +137,7 @@ tester.addTests([
                 ("color.alphaMask2", "modify-inplace",
                  pgext.color.alphaMask, [source_rgba, 1]),
 
+
                 ("filters.shadow", "modify-return",
                  pgext.filters.shadow, [(0, 0, 0), 5, 1, 0.9], source_rgba),
                 ("filters.shadow2", "modify-return",
@@ -138,7 +149,10 @@ tester.addTests([
                  pgext.filters.hvBlur, [6, 1]),
                 ("filters.noise", "modify-inplace",
                  pgext.filters.noise, [55, 2]),
-
+                ("filters.noiseBlur1", "modify-inplace",
+                 pgext.filters.noiseBlur, [5]),
+                ("filters.noiseBlur2", "modify-inplace",
+                 pgext.filters.noiseBlur, [20, 1]),
                 ("filters.scratch", "modify-inplace",
                  pgext.filters.scratch, [5]),
 
